RedisCache

Struct RedisCache 

pub struct RedisCache<'a> {
    pub client: Cow<'a, Client>,
}
A cache implementation that uses a Redis instance to automatically remove the cache entries when their expiration date has passed.

Fields

client: Cow<'a, Client>

Implementations

Source

impl<'a> RedisCache<'a>

pub fn new(client: Cow<'a, Client>) -> Self