Module value_bound_query

Module value_bound_query 

Structs

Prisecter
A struct usually filled in with data directly sent by the ch.tetr.io API You can set values manually but I really couldn’t explain the behavior to you.

Enums

ValueBoundQuery