pub struct Prisecter {
pub pri: f64,
pub sec: f64,
pub ter: f64,
}Expand description
A struct usually filled in with data directly sent by the ch.tetr.io API You can set values manually but I really couldn’t explain the behavior to you.
Fields
pri: f64sec: f64ter: f64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Prisecter
impl<'de> Deserialize<'de> for Prisecter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more