pub struct RedisCache<'a> {
pub client: Cow<'a, Client>,
}Expand description
A cache implementation that uses a Redis instance to automatically remove the cache entries when their expiration date has passed.
Fields
client: Cow<'a, Client>Implementations